@@ -2,8 +2,8 @@
 
 namespace Icinga\Module\Director\Web\Tabs;
 
-use dipl\Translation\TranslationHelper;
-use dipl\Web\Widget\Tabs;
+use gipfl\Translation\TranslationHelper;
+use gipfl\IcingaWeb2\Widget\Tabs;
 
 class ImportTabs extends Tabs
 {
